@@ -1,5 +1,5 @@
 from btcturk_api.exceptions import BTCTurkAuthenticationError
-
+from requests import Response
 import functools
 
 
@@ -7,7 +7,7 @@ def authentication_required(func):
     @functools.wraps(func)
     def wrapper_decorator(*args, **kwargs):
         if not args[0].authenticated:
-            raise BTCTurkAuthenticationError(response=None)
+            raise BTCTurkAuthenticationError(response=Response())
         value = func(*args, **kwargs)
         return value
 
